Properties Methods Events Direct Link

# Class Ext.ensible.cal.DayHeaderTemplate

Package: | Ext.ensible.cal
Defined In: | DayHeaderTemplate.js
Class: | DayHeaderTemplate
Extends: | Object

This is the template used to render the all-day event container used in DayView and WeekView. Internally the majority of the layout logic is deferred to an instance of Ext.ensible.cal.BoxLayoutTemplate.

This template is automatically bound to the underlying event store by the calendar components and expects records of type Ext.ensible.cal.EventRecord.

Note that this template would not normally be used directly. Instead you would use the Ext.ensible.cal.DayViewTemplate that internally creates an instance of this template along with a Ext.ensible.cal.DayBodyTemplate.

## Public Properties

This class has no public properties.

## Public Methods

This class has no public methods.

## Public Events

This class has no public events.